////////////////////////////////////////////////////////////////////////////////
//
//		Licensed Materials - Property of IBM
//  		xxxx-xxx
//		(C) Copyright IBM Corp. 2004. All rights reserved.
//		US Government Users Restricted Rights - Use, duplication or disclosure
//		restricted by GSA ADP Schedule Contract with IBM Corp.
//
// The source code for this program is not published or otherwise
// divested of its trade secrets, irrespective of what has been
// deposited with the U.S. Copyright Office.
//
////////////////////////////////////////////////////////////////////////////////
package com.ibm.debug.idebug.engine;

import java.io.File;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.ui.plugin.AbstractUIPlugin;

/**
 * The main class for the engine plug-in to be used in the desktop.
 */
public class EnginePlugin extends AbstractUIPlugin {
	private static EnginePlugin		plugin				= null;
	private ResourceBundle			resourceBundle		= null;
	private PiclEngineFileLocator	engineFileLocator	= null;

	/**
	 * The constructor.
	 */
	public EnginePlugin() {
		super();
		plugin = this;
		try {
			resourceBundle = ResourceBundle
				.getBundle("com.ibm.debug.pdt.picl.PiclPluginResources");
		} catch (MissingResourceException x) {
			resourceBundle = null;
		}

		engineFileLocator = new PiclEngineFileLocator();
	}

	/**
	 * Returns the shared instance.
	 */
	public static EnginePlugin getDefault() {
		return plugin;
	}
	
	/**
	 * Returns the string from the plugin's resource bundle, or 'key' if not
	 * found.
	 */
	public static String getResourceString(String key) {
		ResourceBundle bundle = EnginePlugin.getDefault().getResourceBundle();
		try {
			return (bundle != null) ? bundle.getString(key) : key;
		} catch (MissingResourceException e) {
			return key;
		}
	}

	/**
	 * Returns the plugin's resource bundle,
	 */
	public ResourceBundle getResourceBundle() {
		return resourceBundle;
	}

	/**
	 * Used to find the specified engine file by searching through the engine
	 * search path.
	 * 
	 * @param filename
	 *            The engine file to search for.
	 * @return Returns the requested file.
	 */
	public File findEngineFile(String filename) {
		return engineFileLocator.findFile(filename);
	}

	private static final String	IBMCopyRight	= "(C) Copyright IBM Corp. 2004. All rights reserved.";
}